@@ -1,12 +1,5 @@
 package PomBase::Chobo;
 
-use strict;
-use warnings;
-
-use 5.020;
-
-our $VERSION = '0.003'; # VERSION
-
 =head1 NAME
 
 PomBase::Chobo - The great new PomBase::Chobo!
@@ -36,6 +29,10 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
+our $VERSION = '0.004'; # VERSION
+
+use 5.020;
+
 use Mouse;
 use Text::CSV;
 
@@ -45,19 +42,11 @@ use PomBase::Chobo::OntologyData;
 
 
 has dbh => (is => 'ro');
-has chado_data => (is => 'ro', init_arg => undef, lazy_build => 1);
 has ontology_data => (is => 'ro', required => 1);
 has parser => (is => 'ro', init_arg => undef, lazy_build => 1);
 
 with 'PomBase::Chobo::Role::ChadoStore';
 
-sub _build_chado_data
-{
-  my $self = shift;
-
-  return PomBase::Chobo::ChadoData->new(dbh => $self->dbh());
-}
-
 sub _build_parser
 {
   my $self = shift;
