@@ -1,7 +1,5 @@
 package PomBase::Chobo::OntologyData;
 
-our $VERSION = '0.003'; # VERSION
-
 =head1 NAME
 
 PomBase::Chobo::OntologyData - An in memory representation of an Ontology
@@ -40,6 +38,8 @@ under the same terms as Perl itself.
 
 =cut
 
+our $VERSION = '0.004'; # VERSION
+
 use Mouse;
 
 use Clone qw(clone);
@@ -219,6 +219,14 @@ sub get_db_names
   return keys %{$self->terms_by_db_name()};
 }
 
+sub accessions_by_db_name
+{
+  my $self = shift;
+  my $db_name = shift;
+
+  return sort keys %{$self->terms_by_db_name()->{$db_name}};
+}
+
 sub get_terms
 {
   my $self = shift;
