@@ -1,7 +1,5 @@
 package PomBase::Chobo::OntologyTerm;
 
-our $VERSION = '0.003'; # VERSION
-
 =head1 NAME
 
 PomBase::Chobo::OntologyTerm - Simple class for accessing term data
@@ -37,6 +35,8 @@ under the same terms as Perl itself.
 
 =cut
 
+our $VERSION = '0.004'; # VERSION
+
 use Mouse;
 use Carp;
 
@@ -55,6 +55,7 @@ has alt_id => (is => 'ro', isa => 'ArrayRef');
 has is_relationshiptype => (is => 'ro', isa => 'Bool');
 has source_file => (is => 'ro', isa => 'Str', required => 1);
 has source_file_line_number => (is => 'ro', isa => 'Str', required => 1);
+has metadata => (is => 'ro');
 
 our @field_names;
 our %field_conf;
@@ -89,9 +90,16 @@ sub alt_ids
         accession => $2,
       };
     } else {
+      my $db_name;
+      if (defined $self->metadata()->{ontology} &&
+          $self->metadata()->{ontology} eq 'ro') {
+        $db_name = 'OBO_REL'
+      } else {
+        $db_name = '_global';
+      }
       {
         id => $val,
-        db_name => '_global',
+        db_name => $db_name,
         accession => $val,
       };
     }
